@@ -1,6 +1,6 @@
 package Test::Class::Moose::Role::Timing;
 {
-  $Test::Class::Moose::Role::Timing::VERSION = '0.07';
+  $Test::Class::Moose::Role::Timing::VERSION = '0.08';
 }
 
 # ABSTRACT: Report timing role
@@ -9,20 +9,28 @@ use Moose::Role;
 use Benchmark qw(timediff timestr :hireswallclock);
 use Test::Class::Moose::Report::Time;
 
+# this seems like some serious abuse of attributes. Plus, time() is only set
+# as a side-effect of _end_benchmark(). I should rethink this. It's hidden
+# from the outside world, but still ...
 has '_start_benchmark' => (
     is            => 'rw',
     isa           => 'Benchmark',
+    lazy          => 1,
+    default       => sub { Benchmark->new },
     documentation => 'Trusted method for Test::Class::Moose',
 );
 
 has '_end_benchmark' => (
     is      => 'rw',
     isa     => 'Benchmark',
-    trigger => sub {
-        my $self = shift;
-        my $time = Test::Class::Moose::Report::Time->new(
-            timediff( $self->_end_benchmark, $self->_start_benchmark ) );
+    lazy    => 1,
+    default => sub {
+        my $self      = shift;
+        my $benchmark = Benchmark->new;
+        my $time      = Test::Class::Moose::Report::Time->new(
+            timediff( $benchmark, $self->_start_benchmark ) );
         $self->time($time);
+        return $benchmark;
     },
     documentation => 'Trusted method for Test::Class::Moose',
 );
@@ -44,7 +52,7 @@ Test::Class::Moose::Role::Timing - Report timing role
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
